# unitorch.cli.models.chatglm

## ChatGLMProcessor

!!! tip
    **`core/process/chatglm`** is the section for configuration of ChatGLMProcessor.

::: unitorch.cli.models.chatglm.ChatGLMProcessor

## ChatGLMForClassification

!!! tip
    **`core/model/classification/chatglm`** is the section for configuration of ChatGLMForClassification.

::: unitorch.cli.models.chatglm.ChatGLMForClassification

## ChatGLMForPretrain

!!! tip
    **`core/model/pretrain/chatglm`** is the section for configuration of ChatGLMForPretrain.

::: unitorch.cli.models.chatglm.ChatGLMForPretrain

## ChatGLMForGeneration

!!! tip
    **`core/model/generation/chatglm`** is the section for configuration of ChatGLMForGeneration.

::: unitorch.cli.models.chatglm.ChatGLMForGeneration
